@@ -285,7 +285,7 @@ function add (args, where, cb) {
         addLocal(p, null, cb)
         break
       case "remote":
-        addRemoteTarball(p.spec, {name : p.name}, null, cb)
+        addRemoteTarball(p.spec, {name : p.name}, null, null, cb)
         break
       case "git":
         addRemoteGit(p.spec, false, cb)
