@@ -1,5 +1,4 @@
-var fs = require("graceful-fs")
-  , assert = require("assert")
+var assert = require("assert")
   , path = require("path")
   , mkdir = require("mkdirp")
   , chownr = require("chownr")
@@ -17,28 +16,28 @@ var fs = require("graceful-fs")
 module.exports = addLocal
 
 function addLocal (p, pkgData, cb_) {
-  assert(typeof p === "string", "must have path")
+  assert(typeof p === "object", "must have spec info")
   assert(typeof cb === "function", "must have callback")
 
   pkgData = pkgData || {}
 
   function cb (er, data) {
     if (er) {
-      log.error("addLocal", "Could not install %s", p)
+      log.error("addLocal", "Could not install %s", p.spec)
       return cb_(er)
     }
     if (data && !data._fromGithub) {
-      data._from = path.relative(npm.prefix, p) || "."
+      data._from = path.relative(npm.prefix, p.spec) || "."
     }
     return cb_(er, data)
   }
 
-  fs.stat(p, function (er, s) {
-    if (er) return cb(er)
-
-    if (s.isDirectory()) addLocalDirectory(p, pkgData, null, cb)
-    else addLocalTarball(p, pkgData, null, cb)
-  })
+  if (p.type === "directory") {
+    addLocalDirectory(p.spec, pkgData, null, cb)
+  }
+  else {
+    addLocalTarball(p.spec, pkgData, null, cb)
+  }
 }
 
 // At this point, if shasum is set, it's something that we've already
@@ -53,24 +52,27 @@ function addLocalDirectory (p, pkgData, shasum, cb) {
     "Adding a cache directory to the cache will make the world implode."))
 
   readJson(path.join(p, "package.json"), false, function (er, data) {
-    er = needName(er, data)
-    er = needVersion(er, data)
-
-    // check that this is what we expected.
-    if (!er && pkgData.name && pkgData.name !== data.name) {
-      er = new Error( "Invalid Package: expected "
-                    + pkgData.name + " but found "
-                    + data.name )
-    }
-
-    if (!er && pkgData.version && pkgData.version !== data.version) {
-      er = new Error( "Invalid Package: expected "
-                    + pkgData.name + "@" + pkgData.version
-                    + " but found "
-                    + data.name + "@" + data.version )
-    }
-
     if (er) return cb(er)
+
+    if (!data.name) {
+      return cb(new Error("No name provided in package.json"))
+    }
+    else if (pkgData.name && pkgData.name !== data.name) {
+      return cb(new Error(
+        "Invalid package: expected " + pkgData.name + " but found " + data.name
+      ))
+    }
+
+    if (!data.version) {
+      return cb(new Error("No version provided in package.json"))
+    }
+    else if (pkgData.version && pkgData.version !== data.version) {
+      return cb(new Error(
+        "Invalid package: expected " + pkgData.name + "@" + pkgData.version +
+          " but found " + data.name + "@" + data.version
+      ))
+    }
+
     deprCheck(data)
 
     // pack to {cache}/name/ver/package.tgz
@@ -112,15 +114,3 @@ function addLocalDirectory (p, pkgData, shasum, cb) {
     }
   })
 }
-
-function needName(er, data) {
-  return er ? er
-       : (data && !data.name) ? new Error("No name provided")
-       : null
-}
-
-function needVersion(er, data) {
-  return er ? er
-       : (data && !data.version) ? new Error("No version provided")
-       : null
-}
