@@ -22,8 +22,7 @@ var EventEmitter = require("events").EventEmitter
   , path = require("path")
   , abbrev = require("abbrev")
   , which = require("which")
-  , semver = require("semver")
-  , RegClient = require("npm-registry-client")
+  , CachingRegClient = require("./cache/caching-client.js")
   , charSpin = require("char-spinner")
 
 npm.config = {
@@ -41,7 +40,6 @@ npm.commands = {}
 npm.rollbacks = []
 
 try {
-  var pv = process.version.replace(/^v/, '')
   // startup, ok to do this synchronously
   var j = JSON.parse(fs.readFileSync(
     path.join(__dirname, "../package.json"))+"")
@@ -351,7 +349,7 @@ function load (npm, cli, cb) {
 
       // at this point the configs are all set.
       // go ahead and spin up the registry client.
-      npm.registry = new RegClient(npm.config)
+      npm.registry = new CachingRegClient(npm.config)
 
       var umask = npm.config.get("umask")
       npm.modes = { exec: 0777 & (~umask)
